@@ -3,7 +3,7 @@ The flanker.addresslib package exposes a simple address parsing library that
 can handle email addresses and urls.
 
 See the address.py module for the public interfaces to the library and the
-parser.py module for the implementation of the recursive decent parser
+parser.py module for the implementation of the recursive descent parser
 used to parse email addresses and urls.
 
 To override the default DNS lookup library or MX Cache, use the
@@ -25,7 +25,7 @@ from flanker.addresslib.plugins import google
 mx_cache = RedisCache()
 dns_lookup = DNSLookup()
 
-YAHOO_PATTERN = re.compile(r'''.*\.yahoodns\.net$''')
+YAHOO_PATTERN = re.compile(r'''mta[0-9]+\.am[0-9]+\.yahoodns\.net$''')
 GMAIL_PATTERN = re.compile(r'''.*gmail-smtp-in\.l\.google.com$''')
 AOL_PATTERN = re.compile(r'''.*\.mx\.aol\.com$''')
 ICLOUD_PATTERN = re.compile(r'''.*\.icloud\.com\.akadns\.net$''')
